@@ -7,7 +7,7 @@ use Env qw( @PATH );
 use File::Spec;
 
 # ABSTRACT: Find or build GNU Make
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 
 my $in_path;
@@ -27,6 +27,20 @@ sub exe
   $class->config('gmake_called');
 }
 
+
+sub alien_helper
+{
+  return {
+    gmake => sub {
+      # return the executable name for GNU make,
+      # usually either make or gmake depending on
+      # the platform and environment
+      my($class) = @_;
+      $class->exe;
+    },
+  }
+}
+
 1;
 
 __END__
@@ -41,7 +55,7 @@ Alien::gmake - Find or build GNU Make
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -70,6 +84,15 @@ environment when you don't.
 
 Return the "name" of GNU make.  Normally this is either C<make> or C<gmake>.
 
+=head1 HELPERS
+
+=head2 gmake
+
+ %{gmake}
+
+Returns either make or gmake depending on how GNU make is called on your 
+system.
+
 =head1 AUTHOR
 
 Graham Ollis <plicease@cpan.org>
